Frequently Asked Questions
---------------------------


**CulebrONT report does not show any QUAST results**

- To observe results on CulebrONT final report you have to transfer the whole directory ``RESULTS``. It contains a Book and QMD subdirectory as well as the ``snakemake-report.htlm`` generated by snakemake argument --report. If you have some troubles in QUAST displaying please transfer QUAST repertory in your local machine or configure your file browser allowing open distant files in local.


**Error validating model from --model argument**

- This error is obtained if you did not bind your $HOME directory to your apptainer. It is necessary to launch culebrONT using ``--apptainer-args '--bind $HOME'`` argument.


**How much space does it take to install the whole CulebrONT dependencies?**

- Built container apptainer.culebront_tools.sif take 3.5G.


**How to include others SLURM options on config.yaml**

   When a SLURM profile is created, default slurm options are created in a 'RESOURCE_MAPPING' dictionary by the profiles/CulebrONT/slurm-submit.py script. You can add other keys into this dictionary (ex. nodelist) and populate the ``config.yaml`` file with these new options.


**Error in Assemblytics log file**

.. code-block:: bash

    Error in revalue(bed$type, c(Repeat_expansion = "Repeat expansion", Repeat_contraction = "Repeat contraction",  : x is not a factor or a character vector.
    Execution halted

After trying the delta files for the failling Assemblytics rules on the Assemblytics webserver, it seems the problem comes from that Assemblytics does not detect any structural variations between the assembly and the reference and so fails to write some of the (graphical) files in connexion with structural variation. Hence, CulebrONT thrown an error when the output files are not found. You can put False to the ASSEMBLYTICS tool in CulebrONT pipeline to override it.


**QUAST takes to much time to run**

Add  the ``--large`` parameter to the QUAST options


**Apptainer and my local environments**

Bind mounts partitions to the apptainer environment using ``--apptainer-args '--bind $YOURMOUNTDISK'``. It allows to detect non-standard mountpoint into the apptainer container. $YOURMOUNTDISK corresponds to the requested partition or volume, and it could be $HOME or another mount path.

**Hmmsearch path is not found running BUSCO using apptainer.culebront_tools image**

Please check if you don't have another instance of BUSCO installed. BUSCO checks the ``config.ini`` file to find binaries such as hmmsearch. We already have detected conflicts because others BUSCO versions were installed on local computers. You could reinitialise $PATH variable before to launch BUSCO using CulebrONT.
